==> kyuubi-hive-jdbc-shaded-1.7.0-sources.jar: org/apache/kyuubi/shade/org/apache/http/conn/ssl/TrustStrategy.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.kyuubi.shade.org.apache.http.conn.ssl;

/**
 * A strategy to establish trustworthiness of certificates without consulting
 * the trust manager configured in the actual SSL context. This interface can be
 * used to override the standard JSSE certificate verification process.
 *
 * @since 4.1
 */
public interface TrustStrategy extends org.apache.http.ssl.TrustStrategy {

    // Empty! Inherits from org.apache.http.ssl.TrustStrategy.

}

==> kyuubi-hive-jdbc-shaded-1.9.1-sources.jar: org/apache/kyuubi/shade/org/apache/http/conn/ssl/TrustStrategy.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.kyuubi.shade.org.apache.http.conn.ssl;

/**
 * A strategy to establish trustworthiness of certificates without consulting
 * the trust manager configured in the actual SSL context. This interface can be
 * used to override the standard JSSE certificate verification process.
 *
 * @since 4.1
 */
public interface TrustStrategy extends org.apache.kyuubi.shade.org.apache.http.ssl.TrustStrategy {

    // Empty! Inherits from org.apache.http.ssl.TrustStrategy.

}
